@@ -262,11 +262,11 @@ def run_cmd(args_list):
     return s_return, s_output, s_err
 
 
-def voxceleb_files_to_metadata(dev_files_path: str, test_files_path: str, otput_file_path: str):
+def voxceleb_files_to_metadata(files_dir: str, part_name: str, otput_file_path: str):
     """
-    Convert VoxCeleb 1 dev and test files to a DataFrame with metadata.
-    :param dev_files_path:
-    :param test_files_path:
+    Convert VoxCeleb files to a DataFrame with metadata.
+    :param files_dir:
+    :param part_name:
     :param otput_file_path:
     :return:
     """
@@ -279,10 +279,7 @@ def voxceleb_files_to_metadata(dev_files_path: str, test_files_path: str, otput_
             dict_metadata['len_sec'].append(librosa.get_duration(filename=file_path))
             dict_metadata['type'].append(type_part)
 
-    files_to_metadata(find_files(dev_files_path, pattern=['.wav']), 'dev')
-
-    if test_files_path is not None:
-        files_to_metadata(find_files(test_files_path, pattern=['.wav']), 'test')
+    files_to_metadata(find_files(files_dir, pattern=['.wav']), part_name)
 
     df_vox1 = pd.DataFrame(data=dict_metadata)
     df_vox1.to_parquet(otput_file_path, compression='gzip')
